Struct odilia_cache::AccessiblePrimitive
source · pub struct AccessiblePrimitive {
pub id: AccessibleId,
pub sender: String,
}Expand description
A struct which represents the bare minimum of an accessible for purposes of caching. This makes some possibly eronious assumptions about what the sender is.
Fields
id: AccessibleIdThe accessible ID in /org/a11y/atspi/accessible/XYZ; note that XYZ may be equal to any positive number, 0, “null”, or “root”.
sender: StringAssuming that the sender is “:x.y”, this stores the (x,y) portion of this sender.
Implementations
sourceimpl AccessiblePrimitive
impl AccessiblePrimitive
pub async fn into_accessible<'a>( self, conn: &Connection ) -> Result<AccessibleProxy<'a>>
pub async fn into_text<'a>(self, conn: &Connection) -> Result<TextProxy<'a>>
pub fn from_event<T: GenericEvent>(event: &T) -> Result<Self, OdiliaError>