Struct odilia_cache::CacheItem

source ·
pub struct CacheItem {
    pub object: AccessiblePrimitive,
    pub app: AccessiblePrimitive,
    pub parent: CacheRef,
    pub index: i32,
    pub children_num: i32,
    pub interfaces: InterfaceSet,
    pub role: Role,
    pub states: StateSet,
    pub text: String,
    pub children: Vec<CacheRef>,
    pub cache: Weak<Cache>,
}
A struct representing an accessible. To get any information from the cache other than the stored information like role, interfaces, and states, you will need to instantiate an atspi::accessible::AccessibleProxy or other *Proxy type from atspi to query further info.

Fields

object: AccessiblePrimitiveapp: AccessiblePrimitiveparent: CacheRefindex: i32children_num: i32interfaces: InterfaceSetrole: Rolestates: StateSettext: Stringchildren: Vec<CacheRef>cache: Weak<Cache>

Implementations

source

impl CacheItem

source

pub fn parent_ref(&mut self) -> OdiliaResult<Arc<RwLock<CacheItem>>>

source

pub async fn from_atspi_event<T: Signified>( event: &T, cache: Weak<Cache>, connection: &Connection ) -> OdiliaResult<Self>

source

pub async fn from_atspi_cache_item( atspi_cache_item: CacheItem, cache: Weak<Cache>, connection: &Connection ) -> OdiliaResult<Self>

source

pub fn get_children(&self) -> OdiliaResult<Vec<Self>>